@@ -1,8 +1,8 @@
-import unittest
 import sys
+import unittest
 
-if __name__ == '__main__':
-    test_suite = unittest.defaultTestLoader.discover('.', '*test*.py')
+if __name__ == "__main__":
+    test_suite = unittest.defaultTestLoader.discover(".", "*test*.py")
     test_runner = unittest.TextTestRunner(resultclass=unittest.TextTestResult)
     result = test_runner.run(test_suite)
     sys.exit(not result.wasSuccessful())
